@@ -85,6 +85,8 @@ def initial_mappings(conf):
 
 
 def profile_id_from_url(url):
+    if url is None:
+        return None
     m = re.search('/([0-9]+)/', url)
     return None if m is None else int(m.group(1))
 
@@ -93,7 +95,10 @@ def profile_url(gsis_id):
     resp, content = new_http().request(urls['gsis_profile'] % gsis_id, 'HEAD')
     if resp['status'] != '301':
         return None
-    return resp['location']
+    loc = resp['location']
+    if not loc.startswith('http://'):
+        loc = 'http://www.nfl.com' + loc
+    return loc
 
 
 def gsis_id(profile_url):
@@ -123,6 +128,31 @@ def try_int(s):
         return 0
 
 
+def first_int(s):
+    m = re.search('[0-9]+', s)
+    if m is None:
+        return 0
+    return int(m.group(0))
+
+
+def first_word(s):
+    m = re.match('\S+', s)
+    if m is None:
+        return ''
+    return m.group(0)
+
+
+def height_as_inches(txt):
+    # Defaults to 0 if `txt` isn't parseable.
+    feet, inches = 0, 0
+    pieces = re.findall('[0-9]+', txt)
+    if len(pieces) >= 1:
+        feet = try_int(pieces[0])
+        if len(pieces) >= 2:
+            inches = try_int(pieces[1])
+    return feet * 12 + inches
+
+
 def meta_from_soup_row(team, soup_row):
     tds, data = [], []
     for td in soup_row.find_all('td'):
@@ -136,16 +166,6 @@ def meta_from_soup_row(team, soup_row):
     else:
         last_name, first_name = map(lambda s: s.strip(), name.split(','))
 
-    # Format the player's height into inches. If we can't parse the data,
-    # defaul height to 0
-    feet, inches = 0, 0
-    pieces = re.findall('[0-9]+', data[4])
-    if len(pieces) >= 1:
-        feet = try_int(pieces[0])
-        if len(pieces) >= 2:
-            inches = try_int(pieces[1])
-    height = feet * 12 + inches
-
     return {
         'team': team,
         'profile_id': profile_id_from_url(profile_url),
@@ -156,8 +176,8 @@ def meta_from_soup_row(team, soup_row):
         'full_name': '%s %s' % (first_name, last_name),
         'position': data[2],
         'status': data[3],
-        'height': height,
-        'weight': data[5],
+        'height': height_as_inches(data[4]),
+        'weight': first_int(data[5]),
         'birthdate': data[6],
         'years_pro': try_int(data[7]),
         'college': data[8],
@@ -198,9 +218,15 @@ def meta_from_profile_html(html):
         fields = {'Height': 'height', 'Weight': 'weight', 'Born': 'birthdate',
                   'College': 'college'}
         for f, key in fields.items():
-            m = re.search('%s:\s+(\S+)' % f, search)
+            m = re.search('%s:\s+([\S ]+)' % f, search)
             if m is not None:
                 meta[key] = m.group(1)
+                if key == 'height':
+                    meta[key] = height_as_inches(meta[key])
+                elif key == 'weight':
+                    meta[key] = first_int(meta[key])
+                elif key == 'birthdate':
+                    meta[key] = first_word(meta[key])
 
         # Experience is a little weirder...
         m = re.search('Experience:\s+([0-9]+)', search)
@@ -348,14 +374,15 @@ def run():
             return t[0], t[1], profile_url(t[0])
         for i, t in enumerate(pool.imap(fetch, players.items()), 1):
             gid, name, purl = t
+            pid = profile_id_from_url(purl)
+
             progress(i, len(players))
-            if pid is None:
+            if purl is None or pid is None:
                 errors.append('Could not get profile URL for (%s, %s)'
                               % (gid, name))
                 continue
 
             assert gid not in metas
-            pid = profile_id_from_url(purl)
             metas[gid] = {'gsis_id': gid, 'gsis_name': name,
                           'profile_url': purl, 'profile_id': pid}
             reverse[pid] = gid
